﻿using System;
using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;
using Artech.BatchJobExecutor.Configuration;

namespace Artech.BatchJobExecutor
{
    [CustomFactory(typeof(BatchJobCustomFactory)), ConfigurationNameMapper(typeof(BatchJobMapper))]
    public class BatchJob
    {
        private IList<JobStep> _activities;

        public IList<JobStep> Activities
        {
            get { return _activities; }
        }

        public BatchJob(IList<JobStep> activities)
        {
            if (activities == null)
            {
                throw new ArgumentNullException("activities");
            }

            if (activities.Count == 0)
            {
                throw new ArgumentException("One or more activities must be included!");
            }

            this._activities = activities;
        }

        public EventHandler<JobStepExecutionArgs> JobStepStarted;
        public EventHandler<JobStepExecutionArgs> JobStepCompleted; 
        public void Start()
        {
            double count = this.Activities.Count;
            int index = 0;
            foreach (JobStep jobStep in this.Activities)
            {
                
                if (this.JobStepStarted != null)
                {
                    this.JobStepStarted(this, new JobStepExecutionArgs() { JobStep = jobStep, Progress = (int)(100 * ((double)index / count)), Index= index+1});
                }
                jobStep.Execute();
                index++;

                if (this.JobStepCompleted != null)
                {
                    this.JobStepCompleted(this, new JobStepExecutionArgs() { JobStep = jobStep, Progress = (int)(100 * ((double)index / count)) , Index= index});
                }
            }
        }

        public JobStepExecutionArgs JobStepExecutionArgs
        {
            get
            {
                throw new System.NotImplementedException();
            }
            set
            {
            }
        }
    }

    public class JobStepExecutionArgs : EventArgs
    {
        public JobStep JobStep
        { get; set; }

        public int Progress
        { get; set; }

        public int Index
        { get; set; }
    }
}
