﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows.Forms;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;
using Artech.BatchJobExecutor.Configuration;

namespace Artech.BatchJobExecutor
{
    public partial class BatchJobExecutorForm : Form
    {
        private IDictionary<string, string> _allBatchJobs;

        public BatchJobExecutorForm()
        {
            InitializeComponent();
        }

        private void BatchJobExecutorForm_Load(object sender, EventArgs e)
        {
            this._allBatchJobs = new Dictionary<string, string>();
            foreach (var batchJob in BatchJobExecutorSettings.GetConfigurationSection().BatchJobs)
            {
                this._allBatchJobs.Add(batchJob.Name, batchJob.Description);
            }

            this.comboBoxBatchJobs.DataSource = this._allBatchJobs.Keys.ToArray<string>();
            this.comboBoxBatchJobs.SelectedItem = BatchJobExecutorSettings.GetConfigurationSection().DefaultBatchJob;
        }

        private void comboBoxBatchJobs_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (this.comboBoxBatchJobs.SelectedItem.ToString() == string.Empty)
            {
                return;
            }
            this.labelBatchDesc.Text = this._allBatchJobs[this.comboBoxBatchJobs.SelectedItem.ToString()];
            LoadJobSteps();
        }

        private void buttonLoad_Click(object sender, EventArgs e)
        {
            LoadJobSteps();
        }

        private void LoadJobSteps()
        {
            this.listViewAllJobStep.Items.Clear();
            string currentBatchJobName = this.comboBoxBatchJobs.SelectedItem.ToString();
            BatchJobEntry currentBatchJob = BatchJobExecutorSettings.GetConfigurationSection().BatchJobs.Get(currentBatchJobName);
            int index = 1;
            foreach (var jobStep in currentBatchJob.Activities)
            {
                ListViewItem item = new ListViewItem(new string[] { index.ToString(), jobStep.Name, "Not Started" });
                this.listViewAllJobStep.Items.Add(item);
                index++;
            }
            this.buttonStart.Enabled = true;
        }

        private void buttonStart_Click(object sender, EventArgs e)
        {
            string currentBatchJobName = this.comboBoxBatchJobs.SelectedItem.ToString();
            BatchJob currentBatchJob = BatchJobFactory.Create(currentBatchJobName);
            currentBatchJob.JobStepStarted += new EventHandler<JobStepExecutionArgs>(this.JobStepStarted);
            currentBatchJob.JobStepCompleted += new EventHandler<JobStepExecutionArgs>(this.JobStepCompleted);
            currentBatchJob.Start();
        }

        private void JobStepStarted(object sender, JobStepExecutionArgs args)
        {
            this.progressBarExecution.Value = args.Progress;
            this.labelJobStep.Text = "Stated:" + (string.IsNullOrEmpty(args.JobStep.Description) ? args.JobStep.Name : args.JobStep.Description);
            this.listViewAllJobStep.Items[args.Index - 1].SubItems[2].Text = "In Progress ...";
        }

        private void JobStepCompleted(object sender, JobStepExecutionArgs args)
        {                 
            this.progressBarExecution.Value = args.Progress;
            this.labelJobStep.Text = "Completed:" + (string.IsNullOrEmpty(args.JobStep.Description)? args.JobStep.Name : args.JobStep.Description);
            this.listViewAllJobStep.Items[args.Index - 1].SubItems[2].Text = "Completed";
        }
    }
}