﻿using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;
using Microsoft.Practices.ObjectBuilder2;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;

namespace Artech.BatchJobExecutor.Configuration
{
    /// <summary>
    /// A <see cref="ICustomFactory"/> to build instances of a <see cref="BatchJob"/>.
    /// </summary>
    public class BatchJobCustomFactory : ICustomFactory
    {
        #region ICustomFactory Members

        /// <summary>
        /// Returns an new instance of the <see cref="BatchJob"/> the receiver knows how to build.
        /// </summary>
        /// <param name="context">The Microsoft.Practices.ObjectBuilder2.IBuilderContext that represents the current building process.</param>
        /// <param name="name">The name of the instance to build, or null.</param>
        /// <param name="configurationSource">The source for configuration objects.</param>
        /// <param name="reflectionCache">The cache to use retrieving reflection information.</param>
        /// <returns>The new <see cref="BatchJob"/> instance.</returns>
        public object CreateObject(IBuilderContext context, string name,IConfigurationSource configurationSource, ConfigurationReflectionCache reflectionCache)
        {
            IList<JobStep> activities = new List<JobStep>();
            BatchJobEntry batchJobEntry = BatchJobExecutorSettings.GetConfigurationSection().BatchJobs.Get(name);
            foreach (JobStepData jobStepData in batchJobEntry.Activities) 
            {
                activities.Add(JobStepCustomFactory.Instance.Create(context, jobStepData, configurationSource, reflectionCache));
            }

            return new BatchJob(activities);
        }

        #endregion
    }
}
