﻿using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using System.Configuration;

namespace Artech.BatchJobExecutor.Configuration
{
    /// <summary>
    /// A <see cref="SerializableConfigurationSection"/> to represent all of the Batch Job Executor related configuration.
    /// </summary>
    public class BatchJobExecutorSettings : SerializableConfigurationSection
    {
        /// <summary>
        /// A <see cref="NamedElementCollection<VariableEntry>"/> to represent all of variable settings.
        /// </summary>
        [ConfigurationProperty("variables", IsRequired = true)]
        public NamedElementCollection<VariableEntry> Variables
        {
            get
            {
                return this["variables"] as NamedElementCollection<VariableEntry>;
            }
        }

        /// <summary>
        /// A <see cref="NamedElementCollection<BatchJobEntry>"/> to reprent all of batch job entries.
        /// </summary>
        [ConfigurationProperty("batchJobs", IsRequired = true)]
        public NamedElementCollection<BatchJobEntry> BatchJobs
        {
            get
            {
                return this["batchJobs"] as NamedElementCollection<BatchJobEntry>;
            }
        }

        /// <summary>
        /// The name of default batch job.
        /// </summary>
        [ConfigurationProperty("defaultBatchJob", IsRequired = true)]
        public string DefaultBatchJob
        {
            get
            {
                return this["defaultBatchJob"] as string;
            }
        }
        
        /// <summary>
        /// Get the current batch job executor settings in the form of <see cref="BatchJobExecutorSettings"/> type.
        /// </summary>
        /// <returns></returns>
        public static BatchJobExecutorSettings GetConfigurationSection()
        {
            return ConfigurationSourceFactory.Create().GetSection("batchJobExecutor") as BatchJobExecutorSettings;
        }

        private static NamedElementCollection<VariableEntry> variables;

        /// <summary>
        /// Apply the variable setting to the statement.
        /// </summary>
        /// <param name="statement">The statement which includes variables.</param>
        /// <returns>The pasrsed statement.</returns>
        public static string ApplyVariable(string statement)
        {
            if (variables == null)
            {
                variables = GetConfigurationSection().Variables;
            }

            foreach (VariableEntry variable in variables)
            {
                statement = statement.Replace("$" + variable.Name+"$", variable.Value);
            }

            return statement;
        }
    }    
}
