﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Artech.BatchJobExecutor.Configuration;

namespace Artech.BatchJobExecutor
{
    [ConfigurationElementType(typeof(DirectoryCreationJobStepData))]
    public class DirectoryCreationJobStep : DirectoryFileJobStep
    {
        private string _directoryToCreate;
        private bool _alwaysCreateNew;

        public string DirectoryToCreate
        {
            get
            {
                return this._directoryToCreate;
            }
        }

        public bool AlwaysCreateNew
        {
            get
            {
                return this._alwaysCreateNew;
            }
        }

        public DirectoryCreationJobStep(string directoryToCreate)
            : this(directoryToCreate, false)
        { }

        public DirectoryCreationJobStep(string directoryToCreate, bool alwaysCreateNew)
        {
            if(string.IsNullOrEmpty(directoryToCreate))
            {
                throw new ArgumentNullException("directoryToCreate");
            }

            this._alwaysCreateNew = alwaysCreateNew;
            this._directoryToCreate = directoryToCreate;
        }

        public override void Execute()
        {
            if (this._alwaysCreateNew)
            {
                if (Directory.Exists(this._directoryToCreate))
                {
                    Directory.Delete(this._directoryToCreate,true);
                }
                Directory.CreateDirectory(this._directoryToCreate);
            }
            else
            {
                if (Directory.Exists(this._directoryToCreate))
                {
                    throw new IOException(string.Format("The directory \"{0}\" does not exist!", this._directoryToCreate));
                }
            }

            Directory.CreateDirectory(this._directoryToCreate);
        }
    }
}
