﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Artech.BatchJobExecutor.Configuration;

namespace Artech.BatchJobExecutor
{
    [ConfigurationElementType(typeof(DirectoryDeletionJobStepData))]
    public class DirectoryDeletionJobStep : DirectoryFileJobStep
    {
        private string _directoryToDelete;
        private bool _throwExceptionIfNotExists;

        public bool ThrowExceptionIfNotExists
        {
            get { return _throwExceptionIfNotExists; }
        }

        public string DirectoryToDelete
        {
            get
            {
                return this._directoryToDelete;
            }
        }

        public DirectoryDeletionJobStep(string directoryToDelete, bool throwExceptionIfNotExists)
        {
            this._directoryToDelete = directoryToDelete;
            this._throwExceptionIfNotExists = throwExceptionIfNotExists;
        }

        public override void Execute()
        {
            if (!Directory.Exists(this._directoryToDelete))
            {
                if (this._throwExceptionIfNotExists)
                {
                    throw new DirectoryNotFoundException(string.Format("The directory \"{0}\" does not exist!", this._directoryToDelete));
                }

                return;
            }

            Directory.Delete(this._directoryToDelete,true);
        }
    }
}
