﻿using System;
using System.IO;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Artech.BatchJobExecutor.Configuration;

namespace Artech.BatchJobExecutor
{
    [ConfigurationElementType(typeof(DirectoryMoveJobStepData))]
    public class DirectoryMoveJobStep : DirectoryFileJobStep
    {
        private string _sourceDirectory;
        private string _destinationDirectory;

        public string SourceDirectory
        {
            get
            {
                return this._sourceDirectory;
            } 
        }

        public string DestinationDirectory
        {
            get
            {
                return this._destinationDirectory;
            } 
        }        

   
        public DirectoryMoveJobStep(string sourceDirectory, string destinationDirectory)
        {
            if (string.IsNullOrEmpty(sourceDirectory))
            {
                throw new ArgumentNullException("sourceDirectory");
            }

            if (string.IsNullOrEmpty(destinationDirectory))
            {
                throw new ArgumentNullException("destinationDirectory");
            }

            this._sourceDirectory = sourceDirectory;
            this._destinationDirectory = destinationDirectory;
        }

      

        public override void Execute()
        {
            if (!Directory.Exists(this._sourceDirectory))
            {
                throw new DirectoryNotFoundException(string.Format("The directory \"{0}\" does not exist!", this._sourceDirectory));
            }

            MoveFiles(this.SourceDirectory, this.DestinationDirectory);
        }

        private void MoveFiles(string source, string destination)
        {
            if (!Directory.Exists(destination))
            {
                Directory.CreateDirectory(destination);
            }    

            foreach (var file in Directory.GetFiles(source))
            {
                string destinationFileName = file.Replace(source, destination);
                File.Copy(file, destinationFileName, true);  
            }

            foreach (var directory in Directory.GetDirectories(source))
            {
                string destinationDirectory = directory.Replace(source, destination);
                MoveFiles(directory, destinationDirectory);
            }
        }
    }
}
