﻿using System;
using System.Diagnostics;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Artech.BatchJobExecutor.Configuration;

namespace Artech.BatchJobExecutor
{
    [ConfigurationElementType(typeof(ExecutableJobStepData))]
    public class ExecutableJobStep : JobStep
    {
        private string _executableFile;
        private string _arguments;
        private bool _waitForProcessExit;

        public bool WaitForProcessExit
        {
            get { return _waitForProcessExit; }
        }
        public string ExecutableFile
        {
            get { return _executableFile; }
        }
        public string Arguments
        {
            get
            {
                return this._arguments;
            }
        }

        public ExecutableJobStep(string executableFile, bool waitForProcessExit)
            : this(executableFile, string.Empty, waitForProcessExit)
        { }

        public ExecutableJobStep(string executableFile)
            : this(executableFile, string.Empty, true)
        { }

        public ExecutableJobStep(string executableFile, string arguments, bool waitForProcessExit)
        {
            if (string.IsNullOrEmpty(executableFile))
            {
                throw new ArgumentNullException("executableFile");
            }

            this._executableFile = executableFile;
            this._arguments = arguments;
            this._waitForProcessExit = waitForProcessExit;
        }

        public override void Execute()
        {
            Process process = null;
            if (string.IsNullOrEmpty(this.Arguments))
            {
                process = Process.Start(this.ExecutableFile);   
            }
            else
            {
                process = Process.Start(this.ExecutableFile, this.Arguments);                
            }

            if (this._waitForProcessExit)
            {
                process.WaitForExit();
            }
        }
    }
}